@@ -28,7 +28,7 @@ log = logging.getLogger(__name__)
 
 @adapter(IField, IDexterityContent, Interface)
 @implementer(IFieldSerializer)
-class DefaultFieldSerializer(object):
+class DefaultFieldSerializer:
     def __init__(self, field, context, request):
         self.context = context
         self.request = request
@@ -78,7 +78,7 @@ class CollectionFieldSerializer(DefaultFieldSerializer):
             for v in value:
                 try:
                     term = value_type.vocabulary.getTerm(v)
-                    values.append({u"token": term.token, u"title": term.title})
+                    values.append({"token": term.token, "title": term.title})
                 except LookupError:
                     log.warning("Term lookup error: %r" % v)
             value = values
@@ -137,22 +137,27 @@ class RichttextFieldSerializer(DefaultFieldSerializer):
 class TextLineFieldSerializer(DefaultFieldSerializer):
     def __call__(self):
         if self.field.getName() != "remoteUrl":
-            return super(TextLineFieldSerializer, self).__call__()
+            return super().__call__()
         value = self.get_value()
         path = replace_link_variables_by_paths(context=self.context, url=value)
         portal = getMultiAdapter(
             (self.context, self.context.REQUEST), name="plone_portal_state"
         ).portal()
-        ref_obj = portal.restrictedTraverse(path, None)
+        # We should traverse unrestricted, just in case that the path to the object
+        # is not all public, we should be able to reach it by finger pointing
+        ref_obj = portal.unrestrictedTraverse(path, None)
         if ref_obj:
             value = ref_obj.absolute_url()
             return json_compatible(value)
-        return json_compatible(path)
+        else:
+            # The URL does not point to an existing object, so just return the value
+            # without value interpolation
+            return json_compatible(value.replace("${portal_url}", ""))
 
 
 @adapter(IField, IDexterityContent, Interface)
 @implementer(IPrimaryFieldTarget)
-class DefaultPrimaryFieldTarget(object):
+class DefaultPrimaryFieldTarget:
     def __init__(self, field, context, request):
         self.context = context
         self.request = request
