@@ -16,7 +16,7 @@ import json
 
 @implementer(ISerializeToJson)
 @adapter(IPloneSiteRoot, Interface)
-class SerializeSiteRootToJson(object):
+class SerializeSiteRootToJson:
     def __init__(self, context, request):
         self.context = context
         self.request = request
