@@ -11,11 +11,9 @@ from zope.schema.interfaces import ITitledTokenizedTerm
 from zope.schema.interfaces import ITokenizedTerm
 from zope.schema.interfaces import IVocabulary
 
-import six
-
 
 @implementer(ISerializeToJson)
-class SerializeVocabLikeToJson(object):
+class SerializeVocabLikeToJson:
     """Base implementation to serialize vocabularies and sources to JSON.
 
     Implements server-side filtering as well as batching.
@@ -83,7 +81,7 @@ class SerializeSourceToJson(SerializeVocabLikeToJson):
 
 @implementer(ISerializeToJson)
 @adapter(ITokenizedTerm, Interface)
-class SerializeTermToJson(object):
+class SerializeTermToJson:
     def __init__(self, context, request):
         self.context = context
         self.request = request
@@ -92,6 +90,6 @@ class SerializeTermToJson(object):
         term = self.context
         token = term.token
         title = term.title if ITitledTokenizedTerm.providedBy(term) else token
-        if isinstance(title, six.binary_type):
+        if isinstance(title, bytes):
             title = title.decode("UTF-8")
         return {"token": token, "title": translate(title, context=self.request)}
