@@ -7,7 +7,7 @@ from zope.publisher.interfaces import IPublishTraverse
 @implementer(IPublishTraverse)
 class AddonsGet(Service):
     def __init__(self, context, request):
-        super(AddonsGet, self).__init__(context, request)
+        super().__init__(context, request)
         self.params = []
         self.addons = Addons(context, request)
 
@@ -26,7 +26,7 @@ class AddonsGet(Service):
                 return []
 
         result = {
-            "items": {"@id": "{}/@addons".format(self.context.absolute_url())},
+            "items": {"@id": f"{self.context.absolute_url()}/@addons"},
         }
         addons_data = []
         for addon in all_addons.values():
