@@ -15,7 +15,7 @@ class GroupsPatch(Service):
     """Updates an existing group."""
 
     def __init__(self, context, request):
-        super(GroupsPatch, self).__init__(context, request)
+        super().__init__(context, request)
         self.params = []
 
     def publishTraverse(self, request, name):
