@@ -16,11 +16,10 @@ from zope.schema._bootstrapinterfaces import RequiredMissing
 from zope.schema.interfaces import ConstraintNotSatisfied
 from zope.schema.interfaces import ValidationError
 
-import six
 import unittest
 
 
-class RequiredField(object):
+class RequiredField:
     """Context manager that will make a field required and back to old state."""
 
     def __init__(self, field):
@@ -55,12 +54,12 @@ class TestDXFieldDeserializer(unittest.TestCase):
         return deserializer(value)
 
     def test_ascii_deserialization_returns_native_string(self):
-        value = self.deserialize("test_ascii_field", u"Foo")
+        value = self.deserialize("test_ascii_field", "Foo")
         self.assertTrue(isinstance(value, str), "Not a <str>")
         self.assertEqual("Foo", value)
 
     def test_asciiline_deserialization_returns_native_string(self):
-        value = self.deserialize("test_asciiline_field", u"Foo")
+        value = self.deserialize("test_asciiline_field", "Foo")
         self.assertTrue(isinstance(value, str), "Not a <str>")
         self.assertEqual("Foo", value)
 
@@ -75,56 +74,54 @@ class TestDXFieldDeserializer(unittest.TestCase):
         self.assertEqual(False, value)
 
     def test_bytes_deserialization_returns_bytestring(self):
-        value = self.deserialize("test_bytes_field", u"Foo")
+        value = self.deserialize("test_bytes_field", "Foo")
         self.assertTrue(isinstance(value, bytes), "Not a <bytes>")
         self.assertEqual(b"Foo", value)
 
     def test_bytesline_deserialization_returns_bytestring(self):
-        value = self.deserialize("test_bytesline_field", u"Foo")
+        value = self.deserialize("test_bytesline_field", "Foo")
         self.assertTrue(isinstance(value, bytes), "Not a <bytes>")
         self.assertEqual(b"Foo", value)
 
     def test_choice_deserialization_returns_vocabulary_item(self):
-        value = self.deserialize("test_choice_field", u"bar")
-        self.assertTrue(isinstance(value, six.text_type), "Not an <unicode>")
-        self.assertEqual(u"bar", value)
+        value = self.deserialize("test_choice_field", "bar")
+        self.assertTrue(isinstance(value, str), "Not an <unicode>")
+        self.assertEqual("bar", value)
 
     def test_choice_deserialization_from_token_returns_vocabulary_value(self):
-        value = self.deserialize("test_choice_field_with_vocabulary", u"token1")
-        self.assertTrue(isinstance(value, six.text_type), "Not an <unicode>")
-        self.assertEqual(u"value1", value)
+        value = self.deserialize("test_choice_field_with_vocabulary", "token1")
+        self.assertTrue(isinstance(value, str), "Not an <unicode>")
+        self.assertEqual("value1", value)
 
     def test_choice_deserialization_from_value_returns_vocabulary_value(self):
-        value = self.deserialize("test_choice_field_with_vocabulary", u"value1")
-        self.assertTrue(isinstance(value, six.text_type), "Not an <unicode>")
-        self.assertEqual(u"value1", value)
+        value = self.deserialize("test_choice_field_with_vocabulary", "value1")
+        self.assertTrue(isinstance(value, str), "Not an <unicode>")
+        self.assertEqual("value1", value)
 
     def test_choice_deserialization_from_term_returns_vocabulary_value(self):
         value = self.deserialize(
             "test_choice_field_with_vocabulary",
-            {u"token": u"token1", u"title": u"title1"},
+            {"token": "token1", "title": "title1"},
         )
-        self.assertTrue(isinstance(value, six.text_type), "Not an <unicode>")
-        self.assertEqual(u"value1", value)
+        self.assertTrue(isinstance(value, str), "Not an <unicode>")
+        self.assertEqual("value1", value)
 
     def test_date_deserialization_returns_date(self):
-        value = self.deserialize("test_date_field", u"2015-12-20")
+        value = self.deserialize("test_date_field", "2015-12-20")
         self.assertTrue(isinstance(value, date))
         self.assertEqual(date(2015, 12, 20), value)
 
     def test_datetime_deserialization_returns_datetime(self):
-        value = self.deserialize("test_datetime_field", u"2015-12-20T10:39:54.361Z")
+        value = self.deserialize("test_datetime_field", "2015-12-20T10:39:54.361Z")
         self.assertTrue(isinstance(value, datetime), "Not a <datetime>")
         self.assertEqual(datetime(2015, 12, 20, 10, 39, 54, 361000), value)
 
     def test_datetime_deserialization_handles_timezone(self):
-        value = self.deserialize("test_datetime_field", u"2015-12-20T10:39:54.361+01")
+        value = self.deserialize("test_datetime_field", "2015-12-20T10:39:54.361+01")
         self.assertEqual(datetime(2015, 12, 20, 9, 39, 54, 361000), value)
 
     def test_datetime_with_tz_deserialization_keeps_timezone(self):
-        value = self.deserialize(
-            "test_datetime_tz_field", u"2015-12-20T10:39:54.361+01"
-        )
+        value = self.deserialize("test_datetime_tz_field", "2015-12-20T10:39:54.361+01")
         self.assertEqual(
             timezone("Europe/Zurich").localize(
                 datetime(2015, 12, 20, 10, 39, 54, 361000)
@@ -133,9 +130,7 @@ class TestDXFieldDeserializer(unittest.TestCase):
         )
 
     def test_datetime_with_tz_deserialization_converts_timezone(self):
-        value = self.deserialize(
-            "test_datetime_tz_field", u"2015-12-20T10:39:54.361-04"
-        )
+        value = self.deserialize("test_datetime_tz_field", "2015-12-20T10:39:54.361-04")
         self.assertEqual(
             timezone("Europe/Zurich").localize(
                 datetime(2015, 12, 20, 15, 39, 54, 361000)
@@ -144,7 +139,7 @@ class TestDXFieldDeserializer(unittest.TestCase):
         )
 
     def test_datetime_with_tz_deserialization_adds_timezone(self):
-        value = self.deserialize("test_datetime_tz_field", u"2015-12-20T10:39:54.361")
+        value = self.deserialize("test_datetime_tz_field", "2015-12-20T10:39:54.361")
         self.assertEqual(
             timezone("Europe/Zurich").localize(
                 datetime(2015, 12, 20, 11, 39, 54, 361000)
@@ -153,9 +148,7 @@ class TestDXFieldDeserializer(unittest.TestCase):
         )
 
     def test_datetime_with_tz_deserialization_handles_dst(self):
-        value = self.deserialize(
-            "test_datetime_tz_field", u"2015-05-20T10:39:54.361+02"
-        )
+        value = self.deserialize("test_datetime_tz_field", "2015-05-20T10:39:54.361+02")
         self.assertEqual(
             timezone("Europe/Zurich").localize(
                 datetime(2015, 5, 20, 10, 39, 54, 361000)
@@ -176,14 +169,14 @@ class TestDXFieldDeserializer(unittest.TestCase):
                 self.deserialize(field_name, None)
 
     def test_text_deserialization_returns_decimal(self):
-        value = self.deserialize("test_decimal_field", u"1.1")
+        value = self.deserialize("test_decimal_field", "1.1")
         self.assertTrue(isinstance(value, Decimal), "Not a <Decimal>")
-        self.assertEqual(Decimal(u"1.1"), value)
+        self.assertEqual(Decimal("1.1"), value)
 
     def test_dict_deserialization_returns_dict(self):
-        value = self.deserialize("test_dict_field", {u"key": u"value"})
+        value = self.deserialize("test_dict_field", {"key": "value"})
         self.assertTrue(isinstance(value, dict), "Not a <dict>")
-        self.assertEqual({u"key": u"value"}, value)
+        self.assertEqual({"key": "value"}, value)
 
     def test_float_deserialization_returns_float(self):
         value = self.deserialize("test_float_field", 1.0)
@@ -191,9 +184,9 @@ class TestDXFieldDeserializer(unittest.TestCase):
         self.assertEqual(1.0, value)
 
     def test_frozenset_deserialization_returns_frozenset(self):
-        value = self.deserialize("test_frozenset_field", [u"foo", u"bar"])
+        value = self.deserialize("test_frozenset_field", ["foo", "bar"])
         self.assertTrue(isinstance(value, frozenset), "Not a <frozenset>")
-        self.assertEqual(frozenset([u"foo", u"bar"]), value)
+        self.assertEqual(frozenset(["foo", "bar"]), value)
 
     def test_int_deserialization_returns_int(self):
         value = self.deserialize("test_int_field", 22)
@@ -207,46 +200,46 @@ class TestDXFieldDeserializer(unittest.TestCase):
 
     def test_list_deserialization_from_tokens_returns_list_of_values(self):
         value = self.deserialize(
-            "test_list_field_with_choice_with_vocabulary", [u"token1", u"token3"]
+            "test_list_field_with_choice_with_vocabulary", ["token1", "token3"]
         )
         self.assertTrue(isinstance(value, list), "Not a <list>")
-        self.assertEqual([u"value1", u"value3"], value)
+        self.assertEqual(["value1", "value3"], value)
 
     def test_list_deserialization_from_values_returns_list_of_values(self):
         value = self.deserialize(
-            "test_list_field_with_choice_with_vocabulary", [u"value1", u"value3"]
+            "test_list_field_with_choice_with_vocabulary", ["value1", "value3"]
         )
         self.assertTrue(isinstance(value, list), "Not a <list>")
-        self.assertEqual([u"value1", u"value3"], value)
+        self.assertEqual(["value1", "value3"], value)
 
     def test_list_deserialization_from_terms_returns_list_of_values(self):
         value = self.deserialize(
             "test_list_field_with_choice_with_vocabulary",
             [
-                {u"token": u"token1", u"title": u"title1"},
-                {u"token": u"token3", u"title": u"title3"},
+                {"token": "token1", "title": "title1"},
+                {"token": "token3", "title": "title3"},
             ],
         )
         self.assertTrue(isinstance(value, list), "Not a <list>")
-        self.assertEqual([u"value1", u"value3"], value)
+        self.assertEqual(["value1", "value3"], value)
 
     def test_set_deserialization_returns_set(self):
         value = self.deserialize("test_set_field", [1, 2, 3])
         self.assertTrue(isinstance(value, set), "Not a <set>")
-        self.assertEqual(set([1, 2, 3]), value)
+        self.assertEqual({1, 2, 3}, value)
 
     def test_text_deserialization_returns_unicode(self):
-        value = self.deserialize("test_text_field", u"Foo")
-        self.assertTrue(isinstance(value, six.text_type), "Not an <unicode>")
-        self.assertEqual(u"Foo", value)
+        value = self.deserialize("test_text_field", "Foo")
+        self.assertTrue(isinstance(value, str), "Not an <unicode>")
+        self.assertEqual("Foo", value)
 
     def test_textline_deserialization_returns_unicode(self):
-        value = self.deserialize("test_textline_field", u"Foo")
-        self.assertTrue(isinstance(value, six.text_type), "Not an <unicode>")
-        self.assertEqual(u"Foo", value)
+        value = self.deserialize("test_textline_field", "Foo")
+        self.assertTrue(isinstance(value, str), "Not an <unicode>")
+        self.assertEqual("Foo", value)
 
     def test_time_deserialization_returns_time(self):
-        value = self.deserialize("test_time_field", u"10:39:54.361Z")
+        value = self.deserialize("test_time_field", "10:39:54.361Z")
         self.assertTrue(isinstance(value, time), "Not a <time>")
         self.assertEqual(time(10, 39, 54, 361000), value)
 
@@ -261,14 +254,14 @@ class TestDXFieldDeserializer(unittest.TestCase):
         self.assertEqual((1, 2, 3), value)
 
     def test_nested_list_deserialization_returns_nested_list(self):
-        value = self.deserialize("test_nested_list_field", [[1, u"foo"], [2, u"bar"]])
+        value = self.deserialize("test_nested_list_field", [[1, "foo"], [2, "bar"]])
         self.assertTrue(isinstance(value, list), "Not a <list>")
         self.assertTrue(isinstance(value[0], tuple), "Not a <tuple>")
         self.assertTrue(isinstance(value[1], tuple), "Not a <tuple>")
 
     def test_nested_dict_deserialization_returns_nested_dict(self):
         value = self.deserialize(
-            "test_nested_dict_field", {u"1": [u"foo", u"bar"], u"2": [u"spam", u"eggs"]}
+            "test_nested_dict_field", {"1": ["foo", "bar"], "2": ["spam", "eggs"]}
         )
         self.assertTrue(isinstance(value, dict), "Not a <dict>")
         self.assertIn("1", value)
@@ -277,55 +270,55 @@ class TestDXFieldDeserializer(unittest.TestCase):
         self.assertTrue(isinstance(value["2"], tuple), "Not a <tuple>")
 
     def test_richtext_deserialization_from_unicode_returns_richtext(self):
-        value = self.deserialize("test_richtext_field", u"<p>a paragraph</p>")
+        value = self.deserialize("test_richtext_field", "<p>a paragraph</p>")
         self.assertTrue(isinstance(value, RichTextValue), "Not a <RichTextValue>")
-        self.assertEqual(u"<p>a paragraph</p>", value.raw)
+        self.assertEqual("<p>a paragraph</p>", value.raw)
 
     def test_richtext_deserialization_from_dict_returns_richtext(self):
-        value = self.deserialize("test_richtext_field", {u"data": u"Some text"})
+        value = self.deserialize("test_richtext_field", {"data": "Some text"})
         self.assertTrue(isinstance(value, RichTextValue), "Not a <RichTextValue>")
-        self.assertEqual(u"Some text", value.raw)
+        self.assertEqual("Some text", value.raw)
 
     def test_richtext_deserialization_sets_mime_type(self):
         value = self.deserialize(
             "test_richtext_field",
-            {u"data": u"Some text", u"content-type": u"text/plain"},
+            {"data": "Some text", "content-type": "text/plain"},
         )
         self.assertEqual("text/plain", value.mimeType)
 
     def test_richtext_deserialization_sets_encoding(self):
         value = self.deserialize(
-            "test_richtext_field", {u"data": u"Some text", u"encoding": u"latin1"}
+            "test_richtext_field", {"data": "Some text", "encoding": "latin1"}
         )
         self.assertEqual("latin1", value.encoding)
 
     def test_richtext_deserialization_fix_apostrophe(self):
-        value = self.deserialize("test_richtext_field", u"<p>char with &#x27;</p>")
+        value = self.deserialize("test_richtext_field", "<p>char with &#x27;</p>")
         self.assertEqual("<p>char with '</p>", value.raw)
 
     def test_namedfield_deserialization_decodes_value(self):
         value = self.deserialize(
             "test_namedfile_field",
-            {u"data": u"U3BhbSBhbmQgZWdncyE=", u"encoding": u"base64"},
+            {"data": "U3BhbSBhbmQgZWdncyE=", "encoding": "base64"},
         )
         self.assertEqual(b"Spam and eggs!", value.data)
 
     def test_namedfield_deserialization_sets_content_type(self):
         value = self.deserialize(
             "test_namedfile_field",
-            {u"data": u"Spam and eggs!", u"content-type": u"text/plain"},
+            {"data": "Spam and eggs!", "content-type": "text/plain"},
         )
         self.assertEqual("text/plain", value.contentType)
 
     def test_namedfield_deserialization_sets_filename(self):
         value = self.deserialize(
             "test_namedfile_field",
-            {u"data": u"Spam and eggs!", u"filename": u"doc.txt"},
+            {"data": "Spam and eggs!", "filename": "doc.txt"},
         )
         self.assertEqual("doc.txt", value.filename)
 
     def test_namedfile_deserialization_returns_namedfile(self):
-        value = self.deserialize("test_namedfile_field", {u"data": u"Spam and eggs!"})
+        value = self.deserialize("test_namedfile_field", {"data": "Spam and eggs!"})
         self.assertTrue(isinstance(value, namedfile.NamedFile), "Not a <NamedFile>")
         self.assertEqual(b"Spam and eggs!", value.data)
 
@@ -333,18 +326,16 @@ class TestDXFieldDeserializer(unittest.TestCase):
         value = self.deserialize(
             "test_namedimage_field",
             {
-                u"data": u"R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
-                u"encoding": u"base64",
-                u"content-type": u"image/gif",
+                "data": "R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
+                "encoding": "base64",
+                "content-type": "image/gif",
             },
         )
         self.assertTrue(isinstance(value, namedfile.NamedImage), "Not a <NamedImage>")
         self.assertTrue(value.data.startswith(b"GIF89a"))
 
     def test_namedblobfile_deserialization_returns_namedblobfile(self):
-        value = self.deserialize(
-            "test_namedblobfile_field", {u"data": u"Spam and eggs!"}
-        )
+        value = self.deserialize("test_namedblobfile_field", {"data": "Spam and eggs!"})
         self.assertTrue(
             isinstance(value, namedfile.NamedBlobFile), "Not a <NamedBlobFile>"
         )
@@ -354,9 +345,9 @@ class TestDXFieldDeserializer(unittest.TestCase):
         value = self.deserialize(
             "test_namedblobimage_field",
             {
-                u"data": u"R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
-                u"encoding": u"base64",
-                u"content-type": u"image/gif",
+                "data": "R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
+                "encoding": "base64",
+                "content-type": "image/gif",
             },
         )
         self.assertTrue(
@@ -394,7 +385,7 @@ class TestDXFieldDeserializer(unittest.TestCase):
                 "DXTestDocument", id="doc2", title="Referenceable Document"
             )
         ]
-        value = self.deserialize("test_relationchoice_field", six.text_type(doc2.UID()))
+        value = self.deserialize("test_relationchoice_field", str(doc2.UID()))
         self.assertEqual(doc2, value)
 
     def test_relationchoice_deserialization_from_url_returns_document(self):
@@ -403,9 +394,7 @@ class TestDXFieldDeserializer(unittest.TestCase):
                 "DXTestDocument", id="doc2", title="Referenceable Document"
             )
         ]
-        value = self.deserialize(
-            "test_relationchoice_field", six.text_type(doc2.absolute_url())
-        )
+        value = self.deserialize("test_relationchoice_field", str(doc2.absolute_url()))
         self.assertEqual(doc2, value)
 
     def test_relationchoice_deserialization_from_path_returns_document(self):
@@ -414,14 +403,14 @@ class TestDXFieldDeserializer(unittest.TestCase):
                 "DXTestDocument", id="doc2", title="Referenceable Document"
             )
         ]
-        value = self.deserialize("test_relationchoice_field", u"/doc2")
+        value = self.deserialize("test_relationchoice_field", "/doc2")
         self.assertEqual(doc2, value)
 
     def test_relationchoice_deserialization_from_invalid_intid_raises(self):
         with self.assertRaises(ValueError) as cm:
             self.deserialize("test_relationchoice_field", 123456789)
         self.assertEqual(
-            str(cm.exception), u"Could not resolve object for intid=123456789"
+            str(cm.exception), "Could not resolve object for intid=123456789"
         )
         self.assertEqual(400, self.request.response.getStatus())
 
@@ -429,11 +418,11 @@ class TestDXFieldDeserializer(unittest.TestCase):
         with self.assertRaises(ValueError) as cm:
             self.deserialize(
                 "test_relationchoice_field",
-                six.text_type("ac12b24913cf45c6863937367aacc263"),
+                "ac12b24913cf45c6863937367aacc263",
             )
         self.assertEqual(
             str(cm.exception),
-            u"Could not resolve object for UID=ac12b24913cf45c6863937367aacc263",
+            "Could not resolve object for UID=ac12b24913cf45c6863937367aacc263",
         )
         self.assertEqual(400, self.request.response.getStatus())
 
@@ -441,21 +430,19 @@ class TestDXFieldDeserializer(unittest.TestCase):
         with self.assertRaises(ValueError) as cm:
             self.deserialize(
                 "test_relationchoice_field",
-                six.text_type("http://nohost/plone/doesnotexist"),
+                "http://nohost/plone/doesnotexist",
             )
         self.assertEqual(
             str(cm.exception),
-            u"Could not resolve object for URL=http://nohost/plone/doesnotexist",
+            "Could not resolve object for URL=http://nohost/plone/doesnotexist",
         )
         self.assertEqual(400, self.request.response.getStatus())
 
     def test_relationchoice_deserialization_from_invalid_path_raises(self):
         with self.assertRaises(ValueError) as cm:
-            self.deserialize(
-                "test_relationchoice_field", six.text_type("/doesnotexist")
-            )
+            self.deserialize("test_relationchoice_field", "/doesnotexist")
         self.assertEqual(
-            str(cm.exception), u"Could not resolve object for path=/doesnotexist"
+            str(cm.exception), "Could not resolve object for path=/doesnotexist"
         )
         self.assertEqual(400, self.request.response.getStatus())
 
@@ -472,7 +459,7 @@ class TestDXFieldDeserializer(unittest.TestCase):
         ]
         value = self.deserialize(
             "test_relationlist_field",
-            [six.text_type(doc2.UID()), six.text_type(doc3.UID())],
+            [str(doc2.UID()), str(doc3.UID())],
         )
         self.assertTrue(isinstance(value, list), "Not a <list>")
         self.assertEqual(doc2, value[0])
@@ -480,16 +467,16 @@ class TestDXFieldDeserializer(unittest.TestCase):
 
     def test_default_deserializer_validates_value(self):
         with self.assertRaises(ValidationError):
-            self.deserialize("test_maxlength_field", u"01234567890")
+            self.deserialize("test_maxlength_field", "01234567890")
 
     def test_datetime_deserializer_handles_invalid_value(self):
         with self.assertRaises(ValueError) as cm:
-            self.deserialize("test_datetime_field", u"2015-15-15T10:39:54.361Z")
-        self.assertEqual(u"Invalid date: 2015-15-15T10:39:54.361Z", str(cm.exception))
+            self.deserialize("test_datetime_field", "2015-15-15T10:39:54.361Z")
+        self.assertEqual("Invalid date: 2015-15-15T10:39:54.361Z", str(cm.exception))
 
     def test_datetime_deserializer_validates_value(self):
         with self.assertRaises(ValidationError):
-            self.deserialize("test_datetime_min_field", u"1999-12-20T10:39:54.361Z")
+            self.deserialize("test_datetime_min_field", "1999-12-20T10:39:54.361Z")
 
     def test_collection_deserializer_validates_value(self):
         with self.assertRaises(ValidationError) as cm:
@@ -498,8 +485,8 @@ class TestDXFieldDeserializer(unittest.TestCase):
         # This validation error is actually produced by the
         # DefaultFieldDeserializer that the CollectionFieldDeserializer will
         # delegate to for deserializing collection items.
-        self.assertEqual(u"Object is of wrong type.", cm.exception.doc())
-        self.assertEqual((b"2", six.integer_types, ""), cm.exception.args)
+        self.assertEqual("Object is of wrong type.", cm.exception.doc())
+        self.assertEqual((b"2", (int,), ""), cm.exception.args)
 
     def test_dict_deserializer_validates_value(self):
         with self.assertRaises(ValidationError) as cm:
@@ -511,45 +498,45 @@ class TestDXFieldDeserializer(unittest.TestCase):
         # We check for two sets of exception details
         # because zope.schema changed its exception...
         self.assertIn(
-            cm.exception.doc(), (u"Object is of wrong type.", u"Invalid int literal.")
+            cm.exception.doc(), ("Object is of wrong type.", "Invalid int literal.")
         )
         self.assertIn(
             cm.exception.args,
             (
-                ("k", six.integer_types, ""),
+                ("k", (int,), ""),
                 ("invalid literal for int() with base 10: 'k'",),
             ),
         )
 
     def test_time_deserializer_handles_invalid_value(self):
         with self.assertRaises(ValueError) as cm:
-            self.deserialize("test_time_field", u"midnight")
-        self.assertEqual(u"Invalid time: midnight", str(cm.exception))
+            self.deserialize("test_time_field", "midnight")
+        self.assertEqual("Invalid time: midnight", str(cm.exception))
 
     def test_time_deserializer_validates_value(self):
         with self.assertRaises(ValidationError) as cm:
-            self.deserialize("test_time_min_field", u"00:39:54.361Z")
-        self.assertEqual(u"Value is too small", cm.exception.doc())
+            self.deserialize("test_time_min_field", "00:39:54.361Z")
+        self.assertEqual("Value is too small", cm.exception.doc())
 
     def test_timedelta_deserializer_handles_invalid_value(self):
         with self.assertRaises(ValueError) as cm:
-            self.deserialize("test_timedelta_field", u"2h")
+            self.deserialize("test_timedelta_field", "2h")
         self.assertIn(
-            u"unsupported type for timedelta seconds component:", str(cm.exception)
+            "unsupported type for timedelta seconds component:", str(cm.exception)
         )
 
     def test_timedelta_deserializer_validates_value(self):
         with self.assertRaises(ValidationError) as cm:
             self.deserialize("test_timedelta_min_field", 50)
-        self.assertEqual(u"Value is too small", cm.exception.doc())
+        self.assertEqual("Value is too small", cm.exception.doc())
 
     def test_namedfield_deserializer_validates_value(self):
         with self.assertRaises(ValidationError) as cm:
             self.deserialize(
                 "test_namedimage_field",
-                {u"data": u"Spam and eggs!", u"content-type": u"text/plain"},
+                {"data": "Spam and eggs!", "content-type": "text/plain"},
             )
-        self.assertEqual(u"Invalid image file", cm.exception.doc())
+        self.assertEqual("Invalid image file", cm.exception.doc())
 
     def test_namedfield_deserializer_download(self):
         # Handle when we post back the GET results.
@@ -557,16 +544,16 @@ class TestDXFieldDeserializer(unittest.TestCase):
 
         self.deserialize(
             "test_namedfile_field",
-            {u"download": u"some download link", u"content-type": u"text/plain"},
+            {"download": "some download link", "content-type": "text/plain"},
         )
 
     def test_richtextfield_deserializer_validates_value(self):
         with self.assertRaises(ValidationError) as cm:
             self.deserialize(
                 "test_richtext_field",
-                {u"data": u"Spam and eggs!", u"content-type": u"text/xml"},
+                {"data": "Spam and eggs!", "content-type": "text/xml"},
             )
-        self.assertEqual(u"Object is of wrong type.", cm.exception.doc())
+        self.assertEqual("Object is of wrong type.", cm.exception.doc())
 
     def test_relationchoicefield_deserializer_validates_value(self):
         self.portal[
@@ -575,17 +562,17 @@ class TestDXFieldDeserializer(unittest.TestCase):
             )
         ]
         with self.assertRaises(ValidationError) as cm:
-            self.deserialize("test_relationchoice_field", u"/doc3")
-        self.assertEqual(u"Constraint not satisfied", cm.exception.doc())
+            self.deserialize("test_relationchoice_field", "/doc3")
+        self.assertEqual("Constraint not satisfied", cm.exception.doc())
 
     def test_deserialize_with_context_bound_vocabulary(self):
         value = self.deserialize(
-            "test_list_choice_with_context_vocabulary_field", [u"portal_catalog"]
+            "test_list_choice_with_context_vocabulary_field", ["portal_catalog"]
         )
-        self.assertEqual([u"portal_catalog"], value)
+        self.assertEqual(["portal_catalog"], value)
 
     def test_textline_deserializer_strips_value(self):
-        value = self.deserialize("test_textline_field", u"  aa  ")
+        value = self.deserialize("test_textline_field", "  aa  ")
         self.assertEqual(value, "aa")
 
     def test_default_field_deserializer_validates_value(self):
@@ -616,14 +603,14 @@ class TestDXFieldDeserializer(unittest.TestCase):
         deserializer = getMultiAdapter((field, link, self.request), IFieldDeserializer)
 
         self.assertEqual(
-            u"http://www.plone.com", deserializer(value=u"http://www.plone.com")
+            "http://www.plone.com", deserializer(value="http://www.plone.com")
         )
         self.assertEqual(
-            u"${portal_url}/doc1", deserializer(value=u"http://nohost/plone/doc1")
+            "${portal_url}/doc1", deserializer(value="http://nohost/plone/doc1")
         )
 
         # for other contents/fields does nothing
-        value = self.deserialize("test_textline_field", u"http://www.plone.com")
-        self.assertEqual(u"http://www.plone.com", value)
-        value = self.deserialize("test_textline_field", u"http://nohost/plone/doc1")
+        value = self.deserialize("test_textline_field", "http://www.plone.com")
+        self.assertEqual("http://www.plone.com", value)
+        value = self.deserialize("test_textline_field", "http://nohost/plone/doc1")
         self.assertEqual(self.portal.doc1.absolute_url(), value)
