@@ -1,5 +1,5 @@
 from DateTime import DateTime
-from mock import patch
+from unittest.mock import patch
 from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
 from plone.app.textfield.value import RichTextValue
@@ -48,13 +48,13 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
             self.serialize(self.portal.doc1).get("@type"),
             "The @type attribute should be present.",
         )
-        self.assertEqual(self.serialize(self.portal.doc1)["@type"], u"Document")
+        self.assertEqual(self.serialize(self.portal.doc1)["@type"], "Document")
 
     def test_serialize_returns_title(self):
-        self.assertEqual(self.serialize(self.portal.doc1)["title"], u"Document 1")
+        self.assertEqual(self.serialize(self.portal.doc1)["title"], "Document 1")
 
     def test_serialize_can_read_as_manager(self):
-        self.portal.dxdoc.test_read_permission_field = u"Test Read Permission"
+        self.portal.dxdoc.test_read_permission_field = "Test Read Permission"
         self.workflowTool.doActionFor(self.portal.dxdoc, "publish")
         setRoles(self.portal, TEST_USER_ID, ["Member", "Manager"])
         self.assertIn(
@@ -62,7 +62,7 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
         )
 
     def test_serialize_cannot_read_as_member(self):
-        self.portal.dxdoc.test_read_permission_field = u"Test Read Permission"
+        self.portal.dxdoc.test_read_permission_field = "Test Read Permission"
         self.workflowTool.doActionFor(self.portal.dxdoc, "publish")
         setRoles(self.portal, TEST_USER_ID, ["Member"])
         self.assertNotIn(
@@ -70,21 +70,19 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
         )
 
     def test_serialize_returns_desciption(self):
-        self.portal.doc1.description = u"This is a document"
+        self.portal.doc1.description = "This is a document"
         self.assertEqual(
-            self.serialize(self.portal.doc1)["description"], u"This is a document"
+            self.serialize(self.portal.doc1)["description"], "This is a document"
         )
 
     def test_serialize_returns_rich_text(self):
-        self.portal.doc1.text = RichTextValue(
-            u"Lorem ipsum.", "text/plain", "text/html"
-        )
+        self.portal.doc1.text = RichTextValue("Lorem ipsum.", "text/plain", "text/html")
         self.assertEqual(
             self.serialize(self.portal.doc1).get("text"),
             {
-                u"data": u"<p>Lorem ipsum.</p>",
-                u"content-type": u"text/plain",
-                u"encoding": u"utf-8",
+                "data": "<p>Lorem ipsum.</p>",
+                "content-type": "text/plain",
+                "encoding": "utf-8",
             },
         )
 
@@ -103,18 +101,18 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
     def test_serialize_on_folder_returns_items_attr(self):
         self.portal.invokeFactory("Folder", id="folder1", title="Folder 1")
         self.portal.folder1.invokeFactory("Document", id="doc1")
-        self.portal.folder1.doc1.title = u"Document 1"
-        self.portal.folder1.doc1.description = u"This is a document"
+        self.portal.folder1.doc1.title = "Document 1"
+        self.portal.folder1.doc1.description = "This is a document"
         self.portal.folder1.doc1.reindexObject()
         self.assertEqual(
             self.serialize(self.portal.folder1)["items"],
             [
                 {
-                    u"@id": u"http://nohost/plone/folder1/doc1",
-                    u"@type": u"Document",
-                    u"description": u"This is a document",
-                    u"title": u"Document 1",
-                    u"review_state": u"private",
+                    "@id": "http://nohost/plone/folder1/doc1",
+                    "@type": "Document",
+                    "description": "This is a document",
+                    "title": "Document 1",
+                    "review_state": "private",
                 }
             ],
         )
@@ -124,13 +122,13 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
     ):  # noqa
         self.portal.invokeFactory("Folder", id="folder1", title="Folder 1")
         self.portal.folder1.invokeFactory("Document", id="doc1")
-        self.portal.folder1.doc1.title = u"Document 1"
-        self.portal.folder1.doc1.description = u"This is a document"
+        self.portal.folder1.doc1.title = "Document 1"
+        self.portal.folder1.doc1.description = "This is a document"
         self.portal.folder1.doc1.reindexObject()
 
         self.portal.folder1.invokeFactory("Document", id="doc2")
-        self.portal.folder1.doc2.title = u"Document 2"
-        self.portal.folder1.doc2.description = u"Second doc"
+        self.portal.folder1.doc2.title = "Document 2"
+        self.portal.folder1.doc2.description = "Second doc"
         self.portal.folder1.doc2.reindexObject()
 
         # Change GOPIP (getObjectPositionInParent) based order
@@ -140,18 +138,18 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
             self.serialize(self.portal.folder1)["items"],
             [
                 {
-                    u"@id": u"http://nohost/plone/folder1/doc2",
-                    u"@type": u"Document",
-                    u"description": u"Second doc",
-                    u"title": u"Document 2",
-                    u"review_state": u"private",
+                    "@id": "http://nohost/plone/folder1/doc2",
+                    "@type": "Document",
+                    "description": "Second doc",
+                    "title": "Document 2",
+                    "review_state": "private",
                 },
                 {
-                    u"@id": u"http://nohost/plone/folder1/doc1",
-                    u"@type": u"Document",
-                    u"description": u"This is a document",
-                    u"title": u"Document 1",
-                    u"review_state": u"private",
+                    "@id": "http://nohost/plone/folder1/doc1",
+                    "@type": "Document",
+                    "description": "This is a document",
+                    "title": "Document 1",
+                    "review_state": "private",
                 },
             ],
         )
@@ -193,7 +191,7 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
             self.serialize(self.portal).get("@type"),
             "The @type attribute should be present.",
         )
-        self.assertEqual(self.serialize(self.portal)["@type"], u"Plone Site")
+        self.assertEqual(self.serialize(self.portal)["@type"], "Plone Site")
 
     def test_serialize_site_orders_items_by_get_object_position_in_parent(self):  # noqa
         # Change GOPIP (getObjectPositionInParent) based order
@@ -203,18 +201,18 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
             self.serialize(self.portal)["items"],
             [
                 {
-                    u"@id": u"http://nohost/plone/dxdoc",
-                    u"@type": u"DXTestDocument",
-                    u"description": u"",
-                    u"title": u"DX Test Document",
-                    u"review_state": u"private",
+                    "@id": "http://nohost/plone/dxdoc",
+                    "@type": "DXTestDocument",
+                    "description": "",
+                    "title": "DX Test Document",
+                    "review_state": "private",
                 },
                 {
-                    u"@id": u"http://nohost/plone/doc1",
-                    u"@type": u"Document",
-                    u"description": u"",
-                    u"title": u"Document 1",
-                    u"review_state": u"private",
+                    "@id": "http://nohost/plone/doc1",
+                    "@type": "Document",
+                    "description": "",
+                    "title": "Document 1",
+                    "review_state": "private",
                 },
             ],
         )
@@ -226,17 +224,17 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
     def test_serialize_file(self):
         self.portal.invokeFactory("File", id="file1", title="File 1")
         self.portal.file1.file = NamedFile(
-            data=u"Spam and eggs", contentType=u"text/plain", filename=u"test.txt"
+            data="Spam and eggs", contentType="text/plain", filename="test.txt"
         )
 
         file_url = self.portal.file1.absolute_url()
-        download_url = "{0}/@@download/file".format(file_url)
+        download_url = f"{file_url}/@@download/file"
         self.assertEqual(
             {
-                u"filename": u"test.txt",
-                u"content-type": u"text/plain",
-                u"download": download_url,
-                u"size": 13,
+                "filename": "test.txt",
+                "content-type": "text/plain",
+                "download": download_url,
+                "size": 13,
             },
             self.serialize(self.portal.file1).get("file"),
         )
@@ -248,11 +246,11 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
 
     def test_serialize_image(self):
         self.portal.invokeFactory("Image", id="image1", title="Image 1")
-        image_file = os.path.join(os.path.dirname(__file__), u"image.png")
+        image_file = os.path.join(os.path.dirname(__file__), "image.png")
         with open(image_file, "rb") as f:
             image_data = f.read()
         self.portal.image1.image = NamedBlobImage(
-            data=image_data, contentType="image/png", filename=u"image.png"
+            data=image_data, contentType="image/png", filename="image.png"
         )
 
         self.maxDiff = 99999
@@ -260,25 +258,25 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
         with patch.object(storage, "uuid4", return_value="uuid_1"):
             obj_url = self.portal.image1.absolute_url()
             scale_url_uuid = "uuid_1"
-            download_url = u"{}/@@images/{}.png".format(obj_url, scale_url_uuid)
+            download_url = f"{obj_url}/@@images/{scale_url_uuid}.png"
             scales = {
-                u"listing": {u"download": download_url, u"width": 16, u"height": 4},
-                u"icon": {u"download": download_url, u"width": 32, u"height": 8},
-                u"tile": {u"download": download_url, u"width": 64, u"height": 16},
-                u"thumb": {u"download": download_url, u"width": 128, u"height": 33},
-                u"mini": {u"download": download_url, u"width": 200, u"height": 52},
-                u"preview": {u"download": download_url, u"width": 215, u"height": 56},
-                u"large": {u"download": download_url, u"width": 215, u"height": 56},
+                "listing": {"download": download_url, "width": 16, "height": 4},
+                "icon": {"download": download_url, "width": 32, "height": 8},
+                "tile": {"download": download_url, "width": 64, "height": 16},
+                "thumb": {"download": download_url, "width": 128, "height": 33},
+                "mini": {"download": download_url, "width": 200, "height": 52},
+                "preview": {"download": download_url, "width": 215, "height": 56},
+                "large": {"download": download_url, "width": 215, "height": 56},
             }
             self.assertEqual(
                 {
-                    u"filename": u"image.png",
-                    u"content-type": u"image/png",
-                    u"size": 1185,
-                    u"download": download_url,
-                    u"width": 215,
-                    u"height": 56,
-                    u"scales": scales,
+                    "filename": "image.png",
+                    "content-type": "image/png",
+                    "size": 1185,
+                    "download": download_url,
+                    "width": 215,
+                    "height": 56,
+                    "scales": scales,
                 },
                 self.serialize(self.portal.image1)["image"],
             )
@@ -290,7 +288,7 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
     def test_serialize_to_json_collection(self):
         self.portal.invokeFactory("Collection", id="collection1")
         self.portal.collection1.title = "My Collection"
-        self.portal.collection1.description = u"This is a collection with two documents"
+        self.portal.collection1.description = "This is a collection with two documents"
         self.portal.collection1.query = [
             {
                 "i": "portal_type",
@@ -303,26 +301,26 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
         self.portal.doc2.reindexObject()
 
         self.assertEqual(
-            u"Collection", self.serialize(self.portal.collection1).get("@type")
+            "Collection", self.serialize(self.portal.collection1).get("@type")
         )
         self.assertEqual(
-            u"Collection", self.serialize(self.portal.collection1).get("@type")
+            "Collection", self.serialize(self.portal.collection1).get("@type")
         )
         self.assertEqual(
             [
                 {
-                    u"@id": self.portal.doc1.absolute_url(),
-                    u"@type": u"Document",
-                    u"description": u"",
-                    u"title": u"Document 1",
-                    u"review_state": u"private",
+                    "@id": self.portal.doc1.absolute_url(),
+                    "@type": "Document",
+                    "description": "",
+                    "title": "Document 1",
+                    "review_state": "private",
                 },
                 {
-                    u"@id": self.portal.doc2.absolute_url(),
-                    u"@type": u"Document",
-                    u"description": u"",
-                    u"title": u"Document 2",
-                    u"review_state": u"private",
+                    "@id": self.portal.doc2.absolute_url(),
+                    "@type": "Document",
+                    "description": "",
+                    "title": "Document 2",
+                    "review_state": "private",
                 },
             ],
             self.serialize(self.portal.collection1).get("items"),
@@ -331,7 +329,7 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
     def test_serialize_to_json_collection_fullobjects(self):
         self.portal.invokeFactory("Collection", id="collection1")
         self.portal.collection1.title = "My Collection"
-        self.portal.collection1.description = u"This is a collection with two documents"
+        self.portal.collection1.description = "This is a collection with two documents"
         self.portal.collection1.query = [
             {
                 "i": "portal_type",
@@ -344,10 +342,10 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
         self.portal.doc2.reindexObject()
 
         self.assertEqual(
-            u"Collection", self.serialize(self.portal.collection1).get("@type")
+            "Collection", self.serialize(self.portal.collection1).get("@type")
         )
         self.assertEqual(
-            u"Collection", self.serialize(self.portal.collection1).get("@type")
+            "Collection", self.serialize(self.portal.collection1).get("@type")
         )
 
         items = self.serialize(self.portal.collection1, fullobjects=True).get("items")
@@ -360,7 +358,7 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
     def test_serialize_to_json_collection_include_items(self):
         self.portal.invokeFactory("Collection", id="collection1")
         self.portal.collection1.title = "My Collection"
-        self.portal.collection1.description = u"This is a collection with two documents"
+        self.portal.collection1.description = "This is a collection with two documents"
         self.portal.collection1.query = [
             {
                 "i": "portal_type",
@@ -373,10 +371,10 @@ class TestSerializeToJsonAdapter(unittest.TestCase):
         self.portal.doc2.reindexObject()
 
         self.assertEqual(
-            u"Collection", self.serialize(self.portal.collection1).get("@type")
+            "Collection", self.serialize(self.portal.collection1).get("@type")
         )
         self.assertEqual(
-            u"Collection", self.serialize(self.portal.collection1).get("@type")
+            "Collection", self.serialize(self.portal.collection1).get("@type")
         )
 
         self.request.form["include_items"] = False
