@@ -1,5 +1,3 @@
-from pkg_resources import get_distribution
-from pkg_resources import parse_version
 from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
 from plone.app.testing import SITE_OWNER_PASSWORD
@@ -10,12 +8,6 @@ from plone.restapi.testing import RelativeSession
 import transaction
 import unittest
 
-zcatalog_version = get_distribution("Products.ZCatalog").version
-if parse_version(zcatalog_version) >= parse_version("5.1"):
-    SUPPORT_NOT_UUID_QUERIES = True
-else:
-    SUPPORT_NOT_UUID_QUERIES = False
-
 
 class TestQuerystringSearchEndpoint(unittest.TestCase):
 
@@ -112,7 +104,7 @@ class TestQuerystringSearchEndpoint(unittest.TestCase):
         self.assertEqual(response.json()["items_total"], 10)
         self.assertEqual(len(response.json()["items"]), 5)
         self.assertNotIn("effective", response.json()["items"][0])
-        self.assertEqual(response.json()["items"][4]["title"], u"Test Document 4")
+        self.assertEqual(response.json()["items"][4]["title"], "Test Document 4")
 
         response = self.api_session.post(
             "/@querystring-search",
@@ -135,12 +127,8 @@ class TestQuerystringSearchEndpoint(unittest.TestCase):
         self.assertEqual(response.json()["items_total"], 10)
         self.assertEqual(len(response.json()["items"]), 5)
         self.assertNotIn("effective", response.json()["items"][0])
-        self.assertEqual(response.json()["items"][4]["title"], u"Test Document 9")
+        self.assertEqual(response.json()["items"][4]["title"], "Test Document 9")
 
-    @unittest.skipIf(
-        not SUPPORT_NOT_UUID_QUERIES,
-        "Skipping because ZCatalog allows not queries on UUIDIndex from >=5.1",
-    )
     def test_querystringsearch_do_not_return_context(self):
         self.portal.invokeFactory("Document", "testdocument2", title="Test Document 2")
         self.doc = self.portal.testdocument
@@ -164,7 +152,7 @@ class TestQuerystringSearchEndpoint(unittest.TestCase):
         self.assertEqual(response.json()["items_total"], 1)
         self.assertEqual(
             response.json()["items"][0]["@id"],
-            "{}/testdocument2".format(self.portal.absolute_url()),
+            f"{self.portal.absolute_url()}/testdocument2",
         )
 
     def test_querystringsearch_sort(self):
@@ -255,9 +243,9 @@ class TestQuerystringSearchEndpoint(unittest.TestCase):
         self.assertEqual(response.json()["items_total"], 10)
         self.assertEqual(
             response.json()["items"][0]["@id"],
-            "{}/testdocument".format(self.portal.absolute_url()),
+            f"{self.portal.absolute_url()}/testdocument",
         )
         self.assertEqual(
             response.json()["items"][-1]["@id"],
-            "{}/testdocument9".format(self.portal.absolute_url()),
+            f"{self.portal.absolute_url()}/testdocument9",
         )
