@@ -7,6 +7,7 @@ from plone.restapi.testing import PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
 from plone.restapi.testing import RelativeSession
 from Products.CMFCore.permissions import SetOwnPassword
 from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.MailHost.interfaces import IMailHost
 from zope.component import getAdapter
 from zope.component import getUtility
@@ -15,12 +16,6 @@ import transaction
 import unittest
 
 
-try:
-    from Products.CMFPlone.interfaces import ISecuritySchema
-except ImportError:
-    from plone.app.controlpanel.security import ISecuritySchema
-
-
 class TestUsersEndpoint(unittest.TestCase):
 
     layer = PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
@@ -51,7 +46,7 @@ class TestUsersEndpoint(unittest.TestCase):
             email="noam.chomsky@example.com",
             username="noam",
             properties=properties,
-            password=u"password",
+            password="password",
         )
         properties = {
             "email": "otheruser@example.com",
@@ -62,7 +57,7 @@ class TestUsersEndpoint(unittest.TestCase):
             email="otheruser@example.com",
             username="otheruser",
             properties=properties,
-            password=u"otherpassword",
+            password="otherpassword",
         )
         transaction.commit()
 
@@ -461,7 +456,7 @@ class TestUsersEndpoint(unittest.TestCase):
             "portrait": {
                 "filename": "image.gif",
                 "encoding": "base64",
-                "data": u"R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
+                "data": "R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
                 "content-type": "image/gif",
             }
         }
@@ -481,7 +476,7 @@ class TestUsersEndpoint(unittest.TestCase):
             "portrait": {
                 "filename": "image.gif",
                 "encoding": "base64",
-                "data": u"R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
+                "data": "R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
                 "content-type": "image/gif",
                 "scale": True,
             }
@@ -502,7 +497,7 @@ class TestUsersEndpoint(unittest.TestCase):
             "portrait": {
                 "filename": "image.gif",
                 "encoding": "base64",
-                "data": u"R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
+                "data": "R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
                 "content-type": "image/gif",
             }
         }
@@ -548,7 +543,7 @@ class TestUsersEndpoint(unittest.TestCase):
             "portrait": {
                 "filename": "image.gif",
                 "encoding": "base64",
-                "data": u"R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
+                "data": "R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=",
                 "content-type": "image/gif",
             }
         }
@@ -715,7 +710,7 @@ class TestUsersEndpoint(unittest.TestCase):
 
         payload = {"reset_token": token, "new_password": "new_password"}
         response = self.api_session.post(
-            "/@users/{}/reset-password".format(user.id), json=payload
+            f"/@users/{user.id}/reset-password", json=payload
         )
 
         self.assertEqual(response.status_code, 200)
@@ -744,7 +739,7 @@ class TestUsersEndpoint(unittest.TestCase):
 
         payload = {"reset_token": token, "new_password": "new_password"}
         response = self.api_session.post(
-            "/@users/{}/reset-password".format(user.getUserName()), json=payload
+            f"/@users/{user.getUserName()}/reset-password", json=payload
         )
 
         self.assertEqual(response.status_code, 200)
@@ -772,7 +767,7 @@ class TestUsersEndpoint(unittest.TestCase):
 
         payload = {"reset_token": token, "new_password": "new_password"}
         response = self.api_session.post(
-            "/@users/{}/reset-password".format(user.getUserName()), json=payload
+            f"/@users/{user.getUserName()}/reset-password", json=payload
         )
 
         self.assertEqual(response.status_code, 200)
