@@ -25,31 +25,31 @@ from zope.schema.vocabulary import SimpleVocabulary
 
 class IDummySchema(model.Schema):
 
-    field1 = schema.Bool(title=u"Foo", description=u"")
+    field1 = schema.Bool(title="Foo", description="")
 
-    field2 = schema.TextLine(title=u"Bar", description=u"")
+    field2 = schema.TextLine(title="Bar", description="")
 
 
 class ITaggedValuesSchema(model.Schema):
 
     form.mode(field_mode_hidden="hidden")
-    field_mode_hidden = schema.TextLine(title=u"ModeHidden", description=u"")
+    field_mode_hidden = schema.TextLine(title="ModeHidden", description="")
 
     form.mode(field_mode_display="display")
-    field_mode_display = schema.TextLine(title=u"ModeDisplay", description=u"")
+    field_mode_display = schema.TextLine(title="ModeDisplay", description="")
 
     form.mode(field_mode_input="input")
-    field_mode_input = schema.TextLine(title=u"ModeInput", description=u"")
+    field_mode_input = schema.TextLine(title="ModeInput", description="")
 
-    field_mode_default = schema.TextLine(title=u"ModeInput", description=u"")
+    field_mode_default = schema.TextLine(title="ModeInput", description="")
 
-    parametrized_widget_field = schema.TextLine(title=u"Parametrized widget field")
+    parametrized_widget_field = schema.TextLine(title="Parametrized widget field")
     form.widget(
         "parametrized_widget_field", a_param="some_value", defaultFactory=lambda: "Foo"
     )
 
     not_parametrized_widget_field = schema.TextLine(
-        title=u"No parametrized widget field"
+        title="No parametrized widget field"
     )
     form.widget(not_parametrized_widget_field=TextWidget)
 
@@ -67,14 +67,14 @@ class TestJsonSchemaUtils(TestCase):
         info = get_jsonschema_properties(self.portal, self.request, fieldsets)
         expected = {
             "field1": {
-                "title": u"Foo",
-                "description": u"",
+                "title": "Foo",
+                "description": "",
                 "factory": "Yes/No",
                 "type": "boolean",
             },
             "field2": {
-                "title": u"Bar",
-                "description": u"",
+                "title": "Bar",
+                "description": "",
                 "factory": "Text line (String)",
                 "type": "string",
             },
@@ -168,7 +168,7 @@ class TestTaggedValuesJsonSchemaUtils(TestCase):
             ttool["TaggedDocument"], self.portal, self.request
         )
         self.assertEqual(
-            u"No parametrized widget field",
+            "No parametrized widget field",
             jsonschema["properties"]["not_parametrized_widget_field"]["title"],
         )
 
@@ -179,7 +179,7 @@ class TestTaggedValuesJsonSchemaUtils(TestCase):
         )
 
         self.assertEqual(
-            u"Foo",
+            "Foo",
             jsonschema["properties"]["parametrized_widget_field"]["widgetOptions"].get(
                 "defaultFactory"
             ),
@@ -195,8 +195,8 @@ class TestJsonSchemaProviders(TestCase):
         self.request = self.layer["request"]
         self.dummy_vocabulary = SimpleVocabulary(
             [
-                SimpleTerm(value=u"foo", title=u"Foo"),
-                SimpleTerm(value=u"bar", title=u"Bar"),
+                SimpleTerm(value="foo", title="Foo"),
+                SimpleTerm(value="bar", title="Bar"),
             ]
         )
 
@@ -207,8 +207,8 @@ class TestJsonSchemaProviders(TestCase):
     def dummy_source_vocab(self, context):
         return SimpleVocabulary(
             [
-                SimpleTerm(value=u"foo", title=u"Foo"),
-                SimpleTerm(value=u"bar", title=u"Bar"),
+                SimpleTerm(value="foo", title="Foo"),
+                SimpleTerm(value="bar", title="Bar"),
             ]
         )
 
@@ -222,8 +222,8 @@ class TestJsonSchemaProviders(TestCase):
             return context.title.upper()
 
         field = schema.TextLine(
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             defaultFactory=uppercased_title_default,
         )
         adapter = getMultiAdapter((field, folder, self.request), IJsonSchemaProvider)
@@ -231,17 +231,17 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "factory": u"Text line (String)",
-                "description": u"My great field",
-                "default": u"MY FOLDER",
+                "title": "My field",
+                "factory": "Text line (String)",
+                "description": "My great field",
+                "default": "MY FOLDER",
             },
             adapter.get_schema(),
         )
 
     def test_textline(self):
         field = schema.TextLine(
-            title=u"My field", description=u"My great field", default=u"foobar"
+            title="My field", description="My great field", default="foobar"
         )
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
@@ -250,19 +250,19 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "factory": u"Text line (String)",
-                "description": u"My great field",
-                "default": u"foobar",
+                "title": "My field",
+                "factory": "Text line (String)",
+                "description": "My great field",
+                "default": "foobar",
             },
             adapter.get_schema(),
         )
 
     def test_text(self):
         field = schema.Text(
-            title=u"My field",
-            description=u"My great field",
-            default=u"Lorem ipsum dolor sit amet",
+            title="My field",
+            description="My great field",
+            default="Lorem ipsum dolor sit amet",
             min_length=10,
         )
         adapter = getMultiAdapter(
@@ -272,11 +272,11 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "description": u"My great field",
-                "factory": u"Text",
+                "title": "My field",
+                "description": "My great field",
+                "factory": "Text",
                 "widget": "textarea",
-                "default": u"Lorem ipsum dolor sit amet",
+                "default": "Lorem ipsum dolor sit amet",
                 "minLength": 10,
             },
             adapter.get_schema(),
@@ -284,7 +284,7 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_bool(self):
         field = schema.Bool(
-            title=u"My field", description=u"My great field", default=False
+            title="My field", description="My great field", default=False
         )
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
@@ -293,9 +293,9 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "boolean",
-                "title": u"My field",
-                "description": u"My great field",
-                "factory": u"Yes/No",
+                "title": "My field",
+                "description": "My great field",
+                "factory": "Yes/No",
                 "default": False,
             },
             adapter.get_schema(),
@@ -303,8 +303,8 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_float(self):
         field = schema.Float(
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             min=0.0,
             max=1.0,
             default=0.5,
@@ -318,9 +318,9 @@ class TestJsonSchemaProviders(TestCase):
                 "minimum": 0.0,
                 "maximum": 1.0,
                 "type": "number",
-                "title": u"My field",
-                "description": u"My great field",
-                "factory": u"Floating-point number",
+                "title": "My field",
+                "description": "My great field",
+                "factory": "Floating-point number",
                 "default": 0.5,
             },
             adapter.get_schema(),
@@ -328,8 +328,8 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_email(self):
         field = Email(
-            title=u"Email",
-            description=u"Email field",
+            title="Email",
+            description="Email field",
             default="foo@bar.com",
             min_length=10,
             max_length=20,
@@ -354,9 +354,9 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_password(self):
         field = schema.Password(
-            title=u"Password",
-            description=u"Password field",
-            default=u"secret",
+            title="Password",
+            description="Password field",
+            default="secret",
             min_length=4,
             max_length=8,
         )
@@ -380,8 +380,8 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_uri(self):
         field = schema.URI(
-            title=u"URI",
-            description=u"URI field",
+            title="URI",
+            description="URI field",
             default="http://foo.bar",
             min_length=10,
             max_length=100,
@@ -406,8 +406,8 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_decimal(self):
         field = schema.Decimal(
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             min=Decimal(0),
             max=Decimal(1),
             default=Decimal(0.5),
@@ -422,8 +422,8 @@ class TestJsonSchemaProviders(TestCase):
                 "maximum": 1.0,
                 "type": "number",
                 "factory": "Floating-point number",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "default": 0.5,
             },
             adapter.get_schema(),
@@ -431,7 +431,7 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_int(self):
         field = schema.Int(
-            title=u"My field", description=u"My great field", min=0, max=100, default=50
+            title="My field", description="My great field", min=0, max=100, default=50
         )
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
@@ -453,8 +453,8 @@ class TestJsonSchemaProviders(TestCase):
     def test_choice(self):
         field = schema.Choice(
             __name__="myfield",
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             vocabulary=self.dummy_vocabulary,
         )
         adapter = getMultiAdapter(
@@ -464,8 +464,8 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "factory": "Choice",
                 "enum": ["foo", "bar"],
                 "enumNames": ["Foo", "Bar"],
@@ -478,8 +478,8 @@ class TestJsonSchemaProviders(TestCase):
     def test_choice_inline_array(self):
         field = schema.Choice(
             __name__="myfield",
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             values=["foo", "bar"],
         )
 
@@ -490,8 +490,8 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "factory": "Choice",
                 "enum": ["foo", "bar"],
                 "enumNames": [None, None],
@@ -503,8 +503,8 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_choice_named_vocab(self):
         field = schema.Choice(
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             vocabulary="plone.app.vocabularies.ReallyUserFriendlyTypes",
         )
         adapter = getMultiAdapter(
@@ -514,11 +514,11 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "factory": "Choice",
                 "vocabulary": {
-                    "@id": u"http://nohost/plone/@vocabularies/plone.app.vocabularies.ReallyUserFriendlyTypes"
+                    "@id": "http://nohost/plone/@vocabularies/plone.app.vocabularies.ReallyUserFriendlyTypes"
                 },  # noqa
             },
             adapter.get_schema(),
@@ -527,8 +527,8 @@ class TestJsonSchemaProviders(TestCase):
     def test_choice_source_vocab(self):
         field = schema.Choice(
             __name__="myfield",
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             source=self.dummy_source_vocab,
         )
         adapter = getMultiAdapter(
@@ -538,8 +538,8 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "factory": "Choice",
                 "enum": ["foo", "bar"],
                 "enumNames": ["Foo", "Bar"],
@@ -551,11 +551,11 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_collection(self):
         field = schema.List(
-            title=u"My field",
-            description=u"My great field",
+            title="My field",
+            description="My great field",
             min_length=1,
             value_type=schema.TextLine(
-                title=u"Text", description=u"Text field", default=u"Default text"
+                title="Text", description="Text field", default="Default text"
             ),
             default=["foobar"],
         )
@@ -566,8 +566,8 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "array",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "factory": "List",
                 "default": ["foobar"],
                 "minItems": 1,
@@ -575,17 +575,17 @@ class TestJsonSchemaProviders(TestCase):
                 "additionalItems": True,
                 "items": {
                     "type": "string",
-                    "title": u"Text",
-                    "description": u"Text field",
+                    "title": "Text",
+                    "description": "Text field",
                     "factory": "Text line (String)",
-                    "default": u"Default text",
+                    "default": "Default text",
                 },
             },
             adapter.get_schema(),
         )
 
         # Test Tuple
-        field = schema.Tuple(title=u"My field", value_type=schema.Int(), default=(1, 2))
+        field = schema.Tuple(title="My field", value_type=schema.Int(), default=(1, 2))
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
         )
@@ -593,14 +593,14 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "array",
-                "title": u"My field",
-                "description": u"",
+                "title": "My field",
+                "description": "",
                 "factory": "Tuple",
                 "uniqueItems": True,
                 "additionalItems": True,
                 "items": {
-                    "title": u"",
-                    "description": u"",
+                    "title": "",
+                    "description": "",
                     "type": "integer",
                     "factory": "Integer",
                 },
@@ -610,7 +610,7 @@ class TestJsonSchemaProviders(TestCase):
         )
 
         # Test Set
-        field = schema.Set(title=u"My field", value_type=schema.TextLine())
+        field = schema.Set(title="My field", value_type=schema.TextLine())
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
         )
@@ -618,14 +618,14 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "array",
-                "title": u"My field",
-                "description": u"",
+                "title": "My field",
+                "description": "",
                 "factory": "Multiple Choice",
                 "uniqueItems": True,
                 "additionalItems": True,
                 "items": {
-                    "title": u"",
-                    "description": u"",
+                    "title": "",
+                    "description": "",
                     "factory": "Text line (String)",
                     "type": "string",
                 },
@@ -636,7 +636,7 @@ class TestJsonSchemaProviders(TestCase):
         # List of choices
         field = schema.List(
             __name__="myfield",
-            title=u"My field",
+            title="My field",
             value_type=schema.Choice(vocabulary=self.dummy_vocabulary),
         )
         adapter = getMultiAdapter(
@@ -646,14 +646,14 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "array",
-                "title": u"My field",
-                "description": u"",
+                "title": "My field",
+                "description": "",
                 "factory": "List",
                 "uniqueItems": True,
                 "additionalItems": True,
                 "items": {
-                    "title": u"",
-                    "description": u"",
+                    "title": "",
+                    "description": "",
                     "factory": "Choice",
                     "type": "string",
                     "enum": ["foo", "bar"],
@@ -667,7 +667,7 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_object(self):
         field = schema.Object(
-            title=u"My field", description=u"My great field", schema=IDummySchema
+            title="My field", description="My great field", schema=IDummySchema
         )
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
@@ -676,20 +676,20 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "object",
-                "title": u"My field",
-                "description": u"My great field",
+                "title": "My field",
+                "description": "My great field",
                 "factory": "File",
                 "properties": {
                     "field1": {
-                        "title": u"Foo",
-                        "description": u"",
-                        "factory": u"Yes/No",
+                        "title": "Foo",
+                        "description": "",
+                        "factory": "Yes/No",
                         "type": "boolean",
                     },
                     "field2": {
-                        "title": u"Bar",
-                        "description": u"",
-                        "factory": u"Text line (String)",
+                        "title": "Bar",
+                        "description": "",
+                        "factory": "Text line (String)",
                         "type": "string",
                     },
                 },
@@ -698,7 +698,7 @@ class TestJsonSchemaProviders(TestCase):
         )
 
     def test_richtext(self):
-        field = RichText(title=u"My field", description=u"My great field")
+        field = RichText(title="My field", description="My great field")
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
         )
@@ -706,9 +706,9 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "factory": u"Rich Text",
-                "description": u"My great field",
+                "title": "My field",
+                "factory": "Rich Text",
+                "description": "My great field",
                 "widget": "richtext",
             },
             adapter.get_schema(),
@@ -716,7 +716,7 @@ class TestJsonSchemaProviders(TestCase):
 
     def test_date(self):
         field = schema.Date(
-            title=u"My field", description=u"My great field", default=date(2016, 1, 1)
+            title="My field", description="My great field", default=date(2016, 1, 1)
         )
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
@@ -725,17 +725,17 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "factory": u"Date",
-                "description": u"My great field",
+                "title": "My field",
+                "factory": "Date",
+                "description": "My great field",
                 "default": date(2016, 1, 1),
-                "widget": u"date",
+                "widget": "date",
             },
             adapter.get_schema(),
         )
 
     def test_datetime(self):
-        field = schema.Datetime(title=u"My field", description=u"My great field")
+        field = schema.Datetime(title="My field", description="My great field")
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
         )
@@ -743,17 +743,17 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "string",
-                "title": u"My field",
-                "factory": u"Date/Time",
-                "description": u"My great field",
-                "widget": u"datetime",
+                "title": "My field",
+                "factory": "Date/Time",
+                "description": "My great field",
+                "widget": "datetime",
             },
             adapter.get_schema(),
         )
 
     def test_jsonfield(self):
         field = JSONField(
-            title=u"My field", description=u"My great field", widget="my_widget_name"
+            title="My field", description="My great field", widget="my_widget_name"
         )
         adapter = getMultiAdapter(
             (field, self.portal, self.request), IJsonSchemaProvider
@@ -762,10 +762,10 @@ class TestJsonSchemaProviders(TestCase):
         self.assertEqual(
             {
                 "type": "dict",
-                "title": u"My field",
+                "title": "My field",
                 "factory": "JSONField",
-                "description": u"My great field",
-                "widget": u"my_widget_name",
+                "description": "My great field",
+                "widget": "my_widget_name",
             },
             adapter.get_schema(),
         )
